<template>
    <Head title="Kemitraan DU/DI"/>
    <AdminMainLayout>
        <div class="card">
            <div class="card-body">
                <div class="card-title">
                    <div class="d-flex justify-content-between align-items-center">
                        <h4>Mitra DU/DI</h4>
                        <BaseButton class="btn-primary" @click="openCreateModal">
                            Tambah Mitra DU/DI
                        </BaseButton>
                    </div>
                </div>
                <div class="table-responsive">
                    <div class="d-flex align-items-center gap-2 mb-3">
                        <BaseInput v-model="search" placeholder="Cari Mitra"/>
                        <i class="fas fa-times text-secondary cursor-pointer" @click="search = ''" v-if="search"/>
                    </div>
                    <table class="table">
                        <thead>
                        <tr>
                            <th>No</th>
                            <th>Nama Mitra</th>
                            <th>Sektor Industri</th>
                            <th>Alamat</th>
                            <th>Kontak</th>
                            <th>Logo</th>
                            <th>Action</th>
                        </tr>
                        </thead>
                        <tbody>
                        <tr v-for="(company, index) in data.data" :key="company.id" v-if="data.data.length > 0">
                            <td>{{ index + 1 }}</td>
                            <td>{{ company.name }}</td>
                            <td>{{ company.sector ?? '-' }}</td>
                            <td>{{ company.address ?? '-'}}</td>
                            <td>
                                <div class="text-secondary">
                                    <ul class="list-unstyled">
                                        <li>
                                            <i class="fas fa-phone"></i> {{ company.phone ?? '-' }}
                                        </li>
                                        <li>
                                            <i class="fas fa-envelope"></i> {{ company.email ?? '-' }}
                                        </li>
                                        <li>
                                            <i class="fas fa-globe"></i> {{ company.website ?? '-' }}
                                        </li>
                                    </ul>
                                </div>
                            </td>

                            <td>
                                <img :src="company.logo ? company.logo : `https://ui-avatars.com/api/?name=${company.name}&background=random&color=fff`"
                                     alt="Logo"
                                     class="img-fluid"
                                     style="max-width: 100px"/>
                            </td>
                            <td>
                                <div class="d-flex gap-2">
                                <span
                                    @click="openEditModal(company)"
                                    class="cursor-pointer">
                                    <i class="fas fa-pen text-secondary"></i>
                                </span>
                                    <span
                                        @click="idDelete = company.id"
                                        class="cursor-pointer">
                                    <i class="fas fa-trash text-danger"></i>
                                </span>
                                </div>
                            </td>
                        </tr>
                        <tr v-else>
                            <td colspan="6" class="text-center">No data available</td>
                        </tr>
                        </tbody>
                    </table>
                    <PaginationLink :links="data.links" class="mt-3"/>
                </div>
            </div>
        </div>

        <!-- Confirmation Modal -->
        <BaseConfirmation
            title="Yakin Menghapus?"
            message="Data yang dihapus tidak dapat dikembalikan"
            :is-visible="idDelete !== null"
            @confirmed="deleteCompany"
            @close="idDelete = null"
        />

        <!-- Modal Create / Edit -->
        <BaseModal
            :title="mode === 1 ? 'Buat Mitra DU/DI' : 'Ubah Mitra DU/DI'"
            :is-visible="isShowModal"
            size="modal-md"
            @close="isShowModal = false"
        >
            <template #body>
                <form @submit.prevent="submit">
                    <BaseInput
                        v-model="form.name"
                        :error-message="form.errors.name"
                        placeholder="Nama Mitra"
                        class="mb-3"
                        label="Nama Mitra"/>
                    <BaseInput
                        v-model="form.sector"
                        placeholder="Sektor Industri : Contoh - Manufaktur, Pertanian, dll"
                        :error-message="form.errors.sector"
                        class="mb-3"
                        label="Sektor Industri"/>
                    <BaseInput
                        v-model="form.address"
                        :error-message="form.errors.address"
                        placeholder="Alamat Mitra"
                        class="mb-3"
                        label="Alamat"/>
                    <BaseInput
                        v-model="form.phone"
                        :error-message="form.errors.phone"
                        type="number"
                        class="mb-3"
                        placeholder="Telepon Mitra"
                        label="Telepon"/>
                    <BaseInput
                        v-model="form.email"
                        :error-message="form.errors.email"
                        type="email"
                        class="mb-3"
                        placeholder="Email Mitra"
                        label="Email"/>
                    <BaseInput
                        v-model="form.website"
                        placeholder="Website Mitra"
                        class="mb-3"
                        :error-message="form.errors.website"
                        label="Website"/>
                    <BaseInputFile
                        type="file"
                        v-model="form.logo"
                        :error-message="form.errors.logo"
                        label="Logo Mitra"
                        @input="form.logo = $event.target.files[0]"/>
                </form>
            </template>
            <template #footer>
                <BaseButton class="btn-primary" @click="submit">
                    {{ mode === 1 ? 'Create' : 'Update' }}
                </BaseButton>
            </template>
    </BaseModal>
    </AdminMainLayout>
</template>

<script setup>
import {Head, router, useForm} from '@inertiajs/vue3';
import PaginationLink from "@/Components/Table/PaginationLink.vue";
import BaseButton from "@/Components/Button/BaseButton.vue";
import {ref, watch} from "vue";
import BaseModal from "@/Components/Modal/BaseModal.vue";
import BaseInput from "@/Components/Forms/BaseInput.vue";
import BaseConfirmation from "@/Components/Modal/BaseConfirmation.vue";
import AdminMainLayout from "@/Layouts/AdminMainLayout.vue";
import debounce from "lodash/debounce";
import BaseInputFile from "@/Components/Forms/BaseInputFile.vue";

defineProps({
    data: {
        type: Object
    }
})

const isShowModal = ref(false);
const mode = ref(1); // 1 = create, 2 = update
const form = useForm({
    id: null,
    name: '',
    sector: '',
    address: '',
    phone: '',
    email: '',
    website: '',
    logo: null
});
const idDelete = ref(null);
const search = ref(window.location.search ? new URLSearchParams(window.location.search).get('search') : '');
const openCreateModal = () => {
    mode.value = 1;
    form.id = null;
    form.name = '';
    form.sector = '';
    form.address = '';
    form.phone = '';
    form.email = '';
    form.website = '';
    form.logo = null;
    isShowModal.value = true;
};

const openEditModal = (value) => {
    console.log(value);
    mode.value = 2;
    form.id = value.id;
    form.name = value.name;
    form.sector = value.sector;
    form.address = value.address;
    form.phone = value.phone;
    form.email = value.email;
    form.website = value.website;
    form.logo = null;
    isShowModal.value = true;
};

const submit = () => {
    console.log(form);
    if (mode.value === 1) {
        form.post('/backoffice/admin/company', {
            forceFormData: true,
            onSuccess: () => {
                isShowModal.value = false;
            }
        });
    } else {
        form.post(`/backoffice/admin/company/${form.id}?_method=PUT`, {
            forceFormData: true,
            onSuccess: () => {
                isShowModal.value = false;
            }
        });
    }
};

const deleteCompany = () => {
    router.delete(`/backoffice/admin/company/${idDelete.value}`, {
        onSuccess: () => {
            idDelete.value = null;
        }
    });
};2

watch(search, debounce((value) => {
    router.get(window.location.pathname, {
        search: value
    });
}, 500));
</script>
